<?php

namespace Schaffen\Gef\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Http\Utils\Response;
use Illuminate\Http\Request;

use Schaffen\Gef\Http\Requests;
use Prettus\Validator\Contracts\ValidatorInterface;
use Prettus\Validator\Exceptions\ValidatorException;
use Schaffen\Gef\Http\Requests\ProdutoFrotaCreateRequest;
use Schaffen\Gef\Http\Requests\ProdutoFrotaUpdateRequest;
use Schaffen\Gef\Models\ProdutoFrota;
use Schaffen\Gef\Repositories\ProdutoFrotaRepository;
use Schaffen\Gef\Services\ProdutoFrotaService;
use Schaffen\Gef\Validators\ProdutoFrotaValidator;

/**
 * Class ProdutoFrotasController.
 *
 * @package namespace Schaffen\Gef\Http\Controllers;
 */
class ProdutoFrotasController extends Controller
{
    /**
     * @var ProdutoFrotaRepository
     */
    protected $repository;

    /**
     * @var ProdutoFrotaService
     */
    protected $service;

    /**
     * ProdutoFrotasController constructor.
     *
     * @param ProdutoFrotaRepository $repository
     * @param ProdutoFrotaValidator $service
     */
    public function __construct(ProdutoFrotaRepository $repository, ProdutoFrotaService $service)
    {
       $this->repository = $repository;
       $this->service = $service;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
   public function index(Request $request)
   {
      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\RequestPrefixCriteria($request, ProdutoFrota::$prefix));
      $produto_frota = $this->repository->all();
      $ret['cols'] = array();
      array_push($ret['cols'], ['field' => "codigo", 'title' => "Código", 'dataType' => 'id', 'filter' => ['codigo' => "text"], 'sortable' => "codigo", 'show' => true]);
      array_push($ret['cols'], ['field' => "produto", 'title' => "Produto", 'dataType' => 'text', 'filter' => ['produto' => "text"], 'sortable' => "produto", 'show' => true]);
      array_push($ret['cols'], ['field' => "categoria", 'title' => "Categoria", 'dataType' => 'text', 'filter' => ['categoria' => "text"], 'sortable' => "categoria", 'show' => true]);
      array_push($ret['cols'], ['field' => "action", 'title' => "Opções", 'dataType' => 'command', 'show' => true]);
      $ret['rows'] = $produto_frota['data'];
      return Response::response(true,null, $ret,null);

   }

    /**
     * Store a newly created resource in storage.
     *
     * @param  ProdutoFrotaCreateRequest $request
     *
     * @return \Illuminate\Http\Response
     *
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function store(ProdutoFrotaCreateRequest $request)
    {
       $response = $this->service->updateOrCreate($request->all());
       return Response::response($response['status'],$response['message'], $response['data'],$response['errors'], $response['http_code']);
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     *
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {

       $this->repository->setPresenter("Schaffen\\Gef\\Presenters\\ProdutoFrotaShowPresenter");
       $produto_frota = $this->repository->find($id);


       return Response::response(true,null, $produto_frota,null);
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  ProdutoFrotaUpdateRequest $request
     * @param  string            $id
     *
     * @return Response
     *
     * @throws \Prettus\Validator\Exceptions\ValidatorException
     */
    public function update(ProdutoFrotaUpdateRequest $request, $id)
    {
       $response = $this->service->updateOrCreate($request->all(),$id);
       return Response::response($response['status'],$response['message'], $response['data'],$response['errors'], $response['http_code']);
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  int $id
     *
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $deleted = $this->repository->delete($id);

        if (request()->wantsJson()) {

            return response()->json([
                'message' => 'ProdutoFrota deleted.',
                'deleted' => $deleted,
            ]);
        }

        return redirect()->back()->with('message', 'ProdutoFrota deleted.');
    }

   public function getConsumiveis()
   {
      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\ProdutosConsumiveisCriteria());
      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\ProdutosProdutoCriteria());
      $produto_frota = $this->repository->all();


      $ret['rows'] = $produto_frota["data"];

      return response()->json([
         'data' => $ret,
      ]);
   }
   public function getAcessorios()
   {
      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\ProdutosAcessoriosCriteria());
      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\ProdutosProdutoCriteria());
      $produto_frota = $this->repository->all();

      $ret['rows'] = $produto_frota["data"];

      return response()->json([
         'data' => $ret,
      ]);
   }
   public function getServicosAcessorios()
   {
      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\ProdutosAcessoriosCriteria());
      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\ProdutosServicoCriteria());
      $produto_frota = $this->repository->all();

      $ret['rows'] = $produto_frota["data"];

      return response()->json([
         'data' => $ret,
      ]);
   }
   public function getServicosConsumivel()
   {
      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\ProdutosConsumiveisCriteria());
      $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\ProdutosServicoCriteria());
      $produto_frota = $this->repository->all();
      
      $ret['rows'] = $produto_frota["data"];

      return response()->json([
         'data' => $ret,
      ]);
   }

}
